/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************
 *                                                                           *
 *   FILE: unur_typedefs.h                                                   *
 *                                                                           *
 *   PURPOSE:                                                                *
 *         typedefs and names of globally used structures                    *
 *         (not already defined in unuran_config.h)                          *
 *                                                                           *
 *****************************************************************************
     $Id: unur_typedefs.h,v 1.1 2002/12/09 19:24:32 leydold Exp $
 *****************************************************************************
 *                                                                           *
 *   Copyright (c) 2000 Wolfgang Hoermann and Josef Leydold                  *
 *   Dept. for Statistics, University of Economics, Vienna, Austria          *
 *                                                                           *
 *   This program is free software; you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
 *   the Free Software Foundation; either version 2 of the License, or       *
 *   (at your option) any later version.                                     *
 *                                                                           *
 *   This program is distributed in the hope that it will be useful,         *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *   GNU General Public License for more details.                            *
 *                                                                           *
 *   You should have received a copy of the GNU General Public License       *
 *   along with this program; if not, write to the                           *
 *   Free Software Foundation, Inc.,                                         *
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA                  *
 *                                                                           *
 *****************************************************************************/

/*---------------------------------------------------------------------------*/
#ifndef UNUR_TYPEDEFS_H_SEEN
#define UNUR_TYPEDEFS_H_SEEN
/*---------------------------------------------------------------------------*/
/* UNURAN objects                                                            */

struct unur_distr;                       /* distribution object              */
typedef struct unur_distr UNUR_DISTR;

struct unur_par;                         /* parameters for generator */
typedef struct unur_par   UNUR_PAR;

struct unur_gen;                         /* generator object         */
typedef struct unur_gen   UNUR_GEN;

/*---------------------------------------------------------------------------*/
/* functions for continuous univariate PDF, CDF, and their derivatives       */

typedef double UNUR_FUNCT_CONT(double x, const struct unur_distr *distr);
typedef double UNUR_FUNCT_DISCR(int x, const struct unur_distr *distr);

/*---------------------------------------------------------------------------*/
/* functions for continuous multivariate PDF, CDF, and their gradients       */

typedef double UNUR_FUNCT_CVEC(const double *x, const struct unur_distr *distr);
typedef int UNUR_VFUNCT_CVEC(double *result, const double *x, const struct unur_distr *distr);

/*---------------------------------------------------------------------------*/
/* structures for auxiliary tools                                            */

struct unur_slist;         /* structure for simple list                      */

/*---------------------------------------------------------------------------*/
#endif  /* UNUR_TYPEDEFS_H_SEEN */
/*---------------------------------------------------------------------------*/



